( cd usr/lib64 ; rm -rf libcryptsetup.so.0 )
( cd usr/lib64 ; ln -sf libcryptsetup.so.0.0.0 libcryptsetup.so.0 )
( cd usr/lib64 ; rm -rf libcryptsetup.so )
( cd usr/lib64 ; ln -sf libcryptsetup.so.0.0.0 libcryptsetup.so )
